==> haskell-tasty-quickcheck-0.11.1-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.11.1
visibility:           public
id:                   tasty-quickcheck-0.11.1-JnL1zGCpTCsAWK8IQVDH0c
key:                  tasty-quickcheck-0.11.1-JnL1zGCpTCsAWK8IQVDH0c
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  bb3880f6927d747b7a15788fff320401
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.11.1-JnL1zGCpTCsAWK8IQVDH0c
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.11.1-8-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.11.1
visibility:           public
id:                   tasty-quickcheck-0.11.1-BdgLwuUVPPX7fK2kBeRBkP
key:                  tasty-quickcheck-0.11.1-BdgLwuUVPPX7fK2kBeRBkP
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  d6d04a614f8cdb97c9175299db5f4e15
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.11.1-BdgLwuUVPPX7fK2kBeRBkP
depends:
    QuickCheck-2.15.0.1-7BzLIlrrsyUAWv4ugiuXtJ base-4.18.2.1
    optparse-applicative-0.18.1.0-EZi3UgmTFLmKW119EQEIXK
    random-1.2.1.3-6l1YOhgkyj83HD6td8a68Q
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-9G3Kf1f0lGYDWNQy5BbNrN

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
